The [MLCommons](https://mlcommons.org), [cTuning foundation](https://cTuning.org) and [cKnowledge.org](https://cKnowledge.org) 
are preparing a unified interface to reproduce results from the MLPerf inference benchmark submission v4.0.
Please feel free to join the testing phase using [GitHub issues](https://github.com/mlcommons/ck/issues)!
